# Les Espaces Vectoriels

## Etudions \\( R^2 \\)

- \\(R^2\\) est un ensemble tq \\( \\{ (a,b)  \vert a \in \mathbb{R} \land b \in \mathbb{R} \\} \\)

## Sous-Espaces Vectoriels

- Soit \\(V \subseteq \mathbb{R} ^n\\)
    - On dit que V est un **Sous-Ensemble Vectoriel** de \\(\mathbb{R}^n\\) ssi
        1) \\(V \neq \emptyset \\)
        2) \\(\forall v_1 \in V \quad \forall v_2 \in V \quad v_1 + v_2 \in V \\)
        3) \\(\forall \lambda \in \mathbb{R} \quad \forall v \in V \quad \lambda v \in V \\)

On peut voir par example que pour \\(\mathbb{R}^3\\) nous avons comme sous-ensemble vectoriel (SEV):
- \\(\\{(0,0)\\}\\) (L'origine du plan)
- \\(\\{\lambda \in \mathbb{R} \vert \lambda(x, y)\\}\\) (une droite passant par l'origine du plan)
- \\(\\{\lambda , \mu \in \mathbb{R} \vert \lambda(x_1, y_1) + \mu(x_2,y_2)\\}\\) (un plan passant par l'origine du repère)
- \\( \mathbb{R}^3 \\) (l'ensemble lui même)

et nous pouvons ettendre cette definition pour \\(\mathbb{R}^N\\)

## Combinaisons linéaires

- Soit \\(V \subseteq \mathbb{R}^n\\) un SEV
    - Soient \\(v_1, ..., v_k \in \mathbb{R} \quad \text{Soit } v \in V\\)
        - On dit que \\(v \\) est une **Combinaison Linéaire** de \\(v_1, ..., v_k\\)
            - Ssi \\(\exists \lambda_1, ...,  \lambda_k \in \mathbb{R} \quad v = \lambda_1 v_1 + ... + \lambda_k v_k\\)
> - Examples
>     - Dans \\(\mathbb{R}^2 \quad (2,3)\\) est une **combinaison linéaire** de (1,0) et (0,1).
>         - On peut multiplier (1,0) par 2 et (0,1) par 3.
> - Contre-Example
>     - Dans \\(\mathbb{R}^3 \quad (1,2,3)\\) n'est pas **combinaison linéaire** de (1,0,0), (0,1,0) et (1,1,0)
>         - Le système d'équation n'a pas de solutions (3 = 0 est faux) donc imposible, Aucuns réel ne peux multiplier ces vecteurs pour donner (1,2,3)

- Soient \\( v_1 ... v_k \in \mathbb{R}^n\\)
    - L'**espace vectoriel** engendré par \\(v_1 ... v_k\\), noté \\(<v_1 ... v_k>\\) est l'ensemble des combinaisons linéaire de \\(v^1...v^k\\)
        - \\(<v_1 ... v_k> = \\{(x_1, ..., x_k) \in \mathbb{R}^n \vert \exists \lambda_1 \in \mathbb{R}...\exists\lambda_k \in \mathbb{R} (x_1, ..., x_k) = \lambda_1 v_1 + ... + \lambda_k v_k\\}\\)

- Soit \\(V \subseteq \mathbb{R}^n \\) un SEV
    - Soit \\(v_1 ... v_k \in V\\)
        - On dit que \\(\\{v_1 ... v_k\\}\\) est **une partie (ou famille) génératrice** de V
            - SSI \\(V = <v_1 ... v_k>\\)
> - Example
>     - \\(\\{(1,0,0), (1,0,1)\\}\\) est **une famille génératrice** de \\(<(1,0,0), (1,0,0)>) = \\\{(x_1, x_2, x_3) \in \mathbb{R}^3 \vert x_2 = 0\\}\\)

Le fait d'ajouter plus de vecteurs que nécéssaires est possible mais n'est pas recommendé car celà ajoute de la complexitée et/ou de l'ambiguitée
lors de la combinaisons des vecteurs.
Il pourrait alors y avoir plusieurs combinaisons différentes pour la même solutions

## Dépendance linéaire

Qu'est ce que des vecteur linéairement dépendants ?

- Soient \\(v_1 ... v_k \in \mathbb{R}^n\\)
    - On dit que les vecteurs \\(v_1 ... v_k\\) sont **linéairement dépendant**
        - SSI \\(\exists \lambda_1, ..., \lambda_k \in \mathbb{R}\\) **non-tous nuls**
            - tel que \\(\lambda_1 v_1 + ... + \lambda_k v_k = \vec{0}\\)
                - C'est un ensemble de vecteurs tel que le vecteurs nul en est leurs combinaison linéaire (ou les facteurs sont différents de tous 0)
    - On dit que les vecteurs \\(v_1 ... v_k\\) sont **linéairement indépendant**
        - SSI \\( \forall \lambda_1, ..., \lambda_k \in \mathbb{R} \displaystyle\sum_{i=1}^{k} \lambda_i vi = 0 \implies \lambda_1 = ... = \lambda_k = 0 \\) 
            - La seule combinaison linéaire pour obtenir le vecteur nul est de multiplier tout les vecteurs par 0

Un ensemble de vecteurs linérairement indépendant est appelé une **Partie ou famille libre **

- Soit \\( L: V_1 \to V_2 \\) Une application linéaire tq \\( Ker(L) = {0} \\) 
    - Si \\( \\{ v_1, ... v_k \\} \\) est une famille libre dans \\( V_1 \\) 
        - Alors \\( \\{ L(v_1), ..., L(v_2) \\} \\)  est une famille libre dans \\( V_2 \\) 

## Base

- Soit \\( V \subseteq \mathbb{R}^n \\) un SEV
    - Soient \\( v_1, ..., v_k \in V \\) 
        - On dit que \\( \\{ v_1, ..., v_k \\}\\) est une **base de V** ssi, et
            - \\( \\{ v_1, ..., v_k \\}\\) est une **famille libre**
            - \\( \\{ v_1, ..., v_k \\}\\) est une **famille génératrice de V**
    - B_1 et B_2 des bases de V:
        - \\( |B_1| = |B_2| \\) 

- Soit \\( V \subset \mathbb{R}^n \\) 
    - Soit \\( B \text{ une Base de } V \\) constituée de \\( k \\) éléments
        - On dit que V est de **Dimention** k. noté \\( dim(V) = k \\) 

- Soit \\( V \\) un sous-espace vectoriel de \\( \mathbb{R}^n \\)
    - Soit \\( B: \\{ v_1, ..., ...v_k \\} \\) une base de V.
        - Soit \\( v \in V \quad v = \lambda_1 * v_1 + ... + \lambda_k * v_k \\) 
            - \\( (\lambda_1, ..., \lambda_k) \\) sont **les coordonées de v dans la base B**


