# Les Matrices

On considére un system:

\\[
    \begin{cases}
        x - 2y + 3z = 4 \\\\
        2x + y - 4z = 3 \\\\
        -3x + 5y -z = 0 
    \end{cases}
\\]

Un système est caractérisé par ses cohéfficients et par les thermes indépendants.
Les nombres sont placés à des positions bien précises.
On peut représenter ces nombres dans un tableau

\\[
    \begin{pmatrix}
        1   &-2 &3  &4 \\\\
        2   &1  &-4 &3 \\\\
        -3  &5  &-1  &0
    \end{pmatrix}
    \text{ On dit que M est une matrice de taille } 3 * 4
\\]

Une matrice de taille \\( m * n \quad  (m,n \in \mathbb{N}_ 0 ) \\) est un tableau
dont les éléments sont rangés selon m lignes et n colonnes

\\[
    A = \begin{pmatrix}
        a_{11} &a_{12} &\cdots &a_{1n} \\\\
        a_{21} &a_{22} &\cdots &\vdots \\\\
        \vdots &\vdots &\ddots &\vdots \\\\
        a_{m1} &\cdots &\cdots &a_{mn}
    \end{pmatrix}
    a_{23} \text{ est situé 2e ligne, 3e colonne } \\\\
    A = (a_{ij} a_{ij} \text{ est un terme de } A)
\\]

## Operations sur les matrices

### Egalitée

 \\( A = B \iff A \text{ et } B \\) ont la même taille et \\( a_{ij} = b_{ij} \quad \forall i,j \\) 

### Transposition

\\( A^t \\)  est la matrice dont les lignes et les colonnes de \\( A \\)  sont inversée

#### Exemple

\\[
    A = \begin{pmatrix}
        1 &2 \\\\
        3 &4
    \end{pmatrix}
    A^t = \begin{pmatrix}
        1 &3 \\\\
        2 &4
    \end{pmatrix}
\\]

### Produit par un scalaire

- Soit \\( A \in \mathbb{R}^{m * n} \quad k \in \mathbb{R}   \\) 
    - La matrice \\( k * a \\) est une matrice \\( B \\) de taille \\( m * n \\) tel que
        - \\( b_{ij} ka_{ij} \quad \forall i,j \\) 

#### Exemple

\\[
    2\begin{pmatrix}
        1 &2 &3\\\\
        4 &5 &6
    \end{pmatrix}
    = \begin{pmatrix}
        2 &4 &6\\\\
        8 &10 &12
    \end{pmatrix}
\\]

### Produit de 2 matrices


\\[
    A * B = C \quad 
    \begin{align}
        c_{ij} &= a_{ij} * b_{ij} + ... a_{in} * b_{nj} \\\\
        &= \displaystyle\sum_{k=1}^{n} a_{ik} * b_{kj}
    \end{align}
\\] 

#### Exemple

\\[
    \begin{pmatrix}
        2 &1 &-1 \\\\
        3 &0 &2
    \end{pmatrix} * 
    \begin{pmatrix}
        1 \\\\
        -2 \\\\
        2 
    \end{pmatrix} =
    \begin{pmatrix}
        2 - 2 - 2 \\\\
        3 + 0 + 4
    \end{pmatrix} =
    \begin{pmatrix}
        -2 \\\\
        7
    \end{pmatrix}
\\]

## Résoudre des système d'équation

### Via l'échelonnement des matrices

1) \\( [A | B] \\)  (A augmenté de B)
2) Echeloner notre matrice ( Grace aux transformations elementaires ci-dessous )
    - \\( L_i \leftrightarrow  L_j\\) (Echange de lignes)
    - \\( L_i \gets \alpha L_i \quad \alpha \in \mathbb{R} \\) 
    - \\( L_i \gets L_i + L_j \\)
3) Revenir au système et trouver S

### Via le calcul de déterminants

Un déterminant est un réel calculé sur une matrice carrée

#### La méthode de Sarros

Cette méthode ne fonctionne que pour les matrices 2x2 et 3x3

##### 2x2

- Soit \\( A \in \mathbb{R}^{2 * 2}  \\) 
\\[
    \det A = 
    \begin{vmatrix}
        a_{11} &a_{12} \\\\
        a_{21} &a_{22}
    \end{vmatrix}
    = (a_{11} * a_{22}) - (a_{12} * a_{21})
\\]

##### 3x3 

- Soit \\( B \in \mathbb{R}^{3 * 3}  \\) 
\\[
    \det B = 
    \begin{vmatrix}
        b_{11} &b_{12} &b_{13} \\\\
        b_{21} &b_{22} &b_{23} \\\\
        b_{31} &b_{32} &b_{33} \\\\
    \end{vmatrix}
        = (b_{11} * b_{22} * b_{33}) + (b_{12} * b_{23} * b_{31}) + (b_{13} * b_{21} * b_{32}) - (b_{13} * b_{22} * b_{31}) - (b_{12} * b_{21} * b_{33}) - (b_{11} * b_{23} * b_{32})
\\]

### La méthode des cofacteurs

Utilisé pour les matrices + grandes ou égales à 3x3

- **Un Mineur** de l'élément \\( a_{ij} \\) est le déterminant de la matrice \\( Aij \\)
    - C'est à dire la matrice \\( A \\) où on a supprimé la ligne i et la conlonne j
        - On la note \\( M_{ij} \\) 

- Le **Cofacteur** de la position ij est le nombre \\( (-1)^{i+j} * M_{ij} \\) 
    - On le note \\( C_{ij} \\) 

On choisit ensuite une ligne a déveloper, au plus il y a de zeros au mieux c'est

- Soit \\( A \in \mathbb{R}^{n * n} \\) 
    - Si on développe la ie Ligne
        - \\( \forall 1 \leq i \leq n \quad \det A = \displaystyle\sum_{j=n}^n a_{ij} * C_{ij} \\) 

#### Inverse d'une matrice

Sachant que l'inverse d'un réel \\( x \\) est \\( x^{-1}  \\) tel que \\( x * x^{-1} = 1\\) 

On peut étendre cette définition aux matrice pour que \\( A * A^{-1} * A = \mathbb{I}  \\) 
Une matrice nxn est inversible ssi \\( \det A \neq 0 \\) 

On peut trouver cette matrice inverse à l'aide de la matrice ompagnon.
1) On vérifie que le détérminanat est différent de 0
2) On applique des transformations élémentaires sur A et sur \\( \mathbb{I} \\) en même temps jusqu'a transformer \\( A \text{ en } \mathbb{I}\\) 

> Mais comment utiliser la matrice inverse pour résoudre un system?

On sait que \\( A \cdot x = b \\) est la représentation d'un système en matrice.
\\[
\begin{align}
    A*x &= b \\\\
    A^{-1} * A * x &= A^{-1} * b \\\\
    \mathbb{I} * x &= A^{-1} * b \\\\
    x &= A^{-1} * b
\end{align}
\\]

où x est la matrice de variable, on aura donc nos solutions directement en mutlipliant nos matrices


