# Limites de fonctions

La limite d'une fonction se note \\[\lim\limits_{x \to a}f(x) = b\\] ou \\[f(x) \xrightarrow[x \to a]{} b\\]

**Idée**: \\(f(x)\\) est aussi proche que je veux de b pour autant que x soit suffisament proche de a

- Soitent \\( f: \mathbb{R} \to \mathbb{R} \quad a,b \in \mathbb{R}\\)
    - On dit que **f tend vers b quand x tend vers a** (\\(f(x) \xrightarrow[x \to a]{}b\\)) si
        - \\(\forall (x\_n) \subseteq dom(f) \quad (x\_n \to a) \implies (f(x\_n) \to b)\\)


Pour considérer \\(f(x) \xrightarrow[x \to a]{} b\\) on demande que \\(a \in adh(dom(f))\\)[^adh]

**Attention** la notation \\(\to \text{ et } \lim\\) ne sont pas les mêmes...
En effet, si \\(a \notin adh(dom(f))\\) alors f(x) tend vers b est vrai mais lim f(x) n'existe pas

**ATTENTION**: pour l'examen! seul manière de le prouver
- Soient \\(A, B \subseteq \mathbb{R} \text{ et } B \subseteq A\\)
    - Si \\(\lim\limits_{x\to a \\\\ x\in A}f(x) = b\\)
        - Alors \\(\lim\limits_{x\to a \\\\ x\in B}f(x) = b\\)

- **idée**: Pour \\(\lim\limits_{x \to a} f(x) = b\\), si \\(a \in dom(f)\\) alors,
    - soit \\(\lim\limits_{x\to a} f(x)\\) n'éxiste pas
    - soit \\(\lim\limits_{x\to a} f(x)\\) existe et vaut f(a) 

## Limites possibles

\\[
    \lim\limits_{x \to \begin{cases}b \in \mathbb{R} \\\\ +\infty \\\\ -\infty\end{cases}}f(x) = \begin{cases}b \in \mathbb{R} \\\\ +\infty \\\\ -\infty\end{cases}
\\]

### Unicitée de la limite

- Soient \\(f : \mathbb{R} \to \mathbb{R} \quad a \in adh(dom(f)) \quad b_1, b_2 \in \mathbb{R} \cup \\{ - \infty , + \infty \\}\\)
    - Si \\(f(x) \xrightarrow[x \to a]{} b_1 et f(x) \xrightarrow[x \to a]{} b_2\\)
        - alors \\(b_1 = b_2\\)

- si \\(\exists (x_n), (y_n) \subseteq dom(f) \text{ tel que } x_n \to a \text{ et } y_n \to a \\) et \\(f(x_n) \to b \text{ et } f(y_n) \to b' ( b \neq b' )\\)
    - alors \\(\lim\limits_{x \to a}f(x)\\) n'existe pas

- S'il existe 2 ensembles \\(A_1, A_2\\) tel que
    - \\(\lim\limits_{x \to a \\\\ x \in A_1}f(x) \text{ et }\lim\limits_{x \to a \\\\ x \in A_2}f(x)\\) existent et sont différentes,
        - Alors \\(\lim\limits_{x\to a} f(x)\\) n'éxiste pas

## Adhérence

l'adherence d'un ensemble coorespond à l'ensemble lui meme uni avec les points adherents

- Soit \\(E \subseteq \mathbb{R}\\)
    - **L'adhérence** de E est l'ens noté \\(adh(E)\\) défini par
        - \\(adh(E) = \\{x \in \mathbb{R} \vert \exists (x\_n) \subseteq E \quad x\_n \to x\\}\\)

- **Remarques**
    - \\(E \subseteq adh(E)\\)
    - \\(adh(E) \nsubseteq E\\)
    - Il peut arriver que \\(E = adh(E)\\)
    - Toutes les suites sont adh à \\(\mathbb{R}\\) et \\(adh(\mathbb{R}) = \mathbb{R}\\)

## Régles de calculus

- Soient \\(f, g: \mathbb{R} \to \mathbb{R} \quad a\in adh(dom(f)) \quad b,c \in \mathbb{R}\\)
    - Si \\(\lim\limits_{x \to a} f(x) = b \text{ et } \lim\limits_{x \to a} g(x) = c\\)
        - Alors \\(\lim\limits_{x \to a} f(x) + g(x) = b + c\\)
        - Alors \\(\lim\limits_{x \to a} f(x) * g(x) = b * c\\)
        - Alors \\(\lim\limits_{x \to a} f(x) / g(x) = b / c (\text{si } c\neq 0)\\)

- **Remarque**
    - \\(dom(f+g) = dom(f) \cap dom(g)\\)
    - \\(dom(f\*g) = dom(f) \cap dom(g)\\)
    - \\(dom(f/g) = dom(f) \cap dom(g)\backslash \\{0\\}\\)

## Théorem de localité

Si nous regardons la fonction sur un interval pertinent pour étudier la convergence de cette fonction, nous pouvons en déduire la convergence en un point de cette fonction

- Soient \\(f : \mathbb{R} \to \mathbb{R} \quad a \in adh(dom(f)) \quad b \in \mathbb{R} \cup \\{-\infty , +\infty \\} \quad r > 0\\)
    - On a \\(\lim\limits_{x\to a} f(x) = b  \text{ ssi } \lim\limits_{x\to a \\\\ x\in [a-r,a+r]} f(x) = b\\)

Notre définition devient alors \\(\forall (x\_n) \subseteq dom(f) \cap A \quad (x\_n \to a) \implies (f(x\_n) \to b) \text{ où } A =[a-r,a+r]\\)

Ce qui veut dire que sur cet interval, nous pouvons y trouver une convergence vers un point. et par unicitée de a limite, si ce point converge, alors ce point converge peut import l'interval de la fonction!

## Théorem d'exhaustivité

Certaines fonctions ne nous permettent pas de connaitre la valeur d'une limite d'un simple coup d'oeuil. ou bien cette valeur peut être ambigue car est sur un "point jonction".
Nous utilisons alors le théorem d'exhaustivité.

Le but est de poser plusieurs sous-ensemble du domaine qui ensemble forment le domaine lui même (exhaustif). et ensuite d'étudier la limite sur chaquns de ces ensembles

par exhaustivitée nous verons si une seule limite ou si plusieurs limites sont présentes... dans le cas d'une seul limite, nous savons que notre limite existe. dans le cas contraire, notre limite n'éxiste pas
à cause de l'unicité de notre limite...

- Soit \\(f: \mathbb{R} \to \mathbb{R} \quad a, b \in \mathbb{R} \quad A\_1, A\_2 \subseteq \mathbb{R}\\)
    - on prend \\(r \in \mathbb{R} \text{ tq } r > 0 \\) et \\([a-r, a+r] \cup dom(f) \subset A_1 \cup A_2\\)
    - Si \\(f(x) \xrightarrow[\substack{x \to a \\\\ x\in A_1}]{} b\\) et \\(f(x) \xrightarrow[\substack{x \to a \\\\ x\in A_2}]{} b\\)

On peut également utiliser cette formule, plus précise dans certains cas:

- Soit \\(f : \mathbb{R} \to \mathbb{R} \quad a\in \mathbb{R} \text{ tq } a \in adh(]-\infty , a[ \cap dom(f)) \text{ et } a \in adh(]a, + \infty [ \cap dom(f))\\)
    - si \\(\lim\limits_{x\to a \\\\ x < a} f(x) \text{ et } \lim\limits_{x\to a \\\\ x > a} f(x)\\) existent, sont égales et valent f(a)
        - alors \\(\lim\limits_{x \to a} f(x)\\) existe et vaut cette valeur commune

## Théorem des valeurs intérmédiaires

On sait que si dans l'interval d'une fonction, le début et la fin de cet interval sont de signes opposés, que nous trouverons au moins un point de la droite qui croisera l'axe des abscisses

- Soient \\(f: [a, b] \to \mathbb{R}\\) une application continue tq \\(f(a) * f(b) < 0\\)
    - Alors il existe \\(\xi \in ]a, b[ \text{ tq } f(\xi ) = 0\\)

> Nous voyons l'importantce des hypothéses! Si la fonction n'est pas une application continue, ou que les signes ne sont pas opposés ou encore que nous regardons la fonction sur un autre ensemble.
> Alors le théorem ne serait pas forcément vrai!

## Convergence dominée

**Attention pour l'examen!!**

La convergence dominée permet de comparer la limite d'une fonction (g(x)) pour en déduire la convergence d'une fonctione plus petit que sa valeur absolue diminuée d'un réel.

- Soient \\(f, g: \mathbb{R} \to \mathbb{R} \quad a \in adh(dom(f)) \quad b \in \mathbb{R}\\)
    - Supposons qu'il existe un réel \\(r > 0 \text{ tel que } [a - r, a + r] \cap dom(f) \subset Dom(g)\\) et \\(\forall x \in [a-r, a+r] \cap dom(f) \quad \vert f(x) - b \vert \leq g(x)\\)
        - alors si \\( g(x) \xrightarrow[x \to a]{} 0, x \in A\\)
            - On a \\(f(x) \xrightarrow[x \to a]{} b, x \in A\\)

## La continuitée des fonctions

On parle d'une fonction continue lorsque tout les points de cette fonction sont continue.
Un point d'une fonction est continue si celui-ci a une limite et que la valeur de cette limite est la valeur de la fonction en ce point

On dit souvent que c'est une fonction qui se trace sans lever le crayon. mais c'est faux!
déjà cela dépend du domaine de la fonction

- Soient \\(f: \mathbb{R} \to \mathbb{R} \quad a \in dom(f)\\)
    - On dit que f est **continue en a**
        - si \\(\lim\limits_{x\to a} f(x) = f(a)\\)
        - (déf par suites) \\(\forall (x\_n) \subseteq dom(f) \quad x\_n \to a \implies f(x\_n) \to f(a)\\)
    - On dit que f est **continue**
        - si \\(\forall a \in dom(f) \quad f \text{ est continue en } a\\)

Finalement, f est continue lorsque un point du domaine ne converge pas... c'est graphiquement lorsqu'il y a une cassure dans la fonction. mais si cette cassure apparait sur un point qui n'est pas dans le domaine, alors la fonction reste continue

On note alors \\(\mathscr{C}(A, B) = \\{f:A\to B \vert f \text{ est une application continue }\\}\\)\

(ex: \\(f(x) = x^2 \qquad f \in \mathscr{C}(\mathbb{R}, \mathbb{R})\\))


### Régles de calculs 

- Soient \\(f, g: \mathbb{R} \to \mathbb{R} \quad a\in dom(f) \quad a\in dom(g)\\)
    - Si f et g sont continue en a
        - Alors \\(f + g\\) est aussi continue en a
        - Alors \\(f * g\\) est aussi continue en a
        - Alors \\(f / g\\) est aussi continue en a (si \\(g(a) \neq 0\\))
    - Si f est continue en \\(a \in dom(f)\\) et g est continue en \\(f(a) \in dom(g)\\) 
        - alors \\(g \circ f\\) est continue en a

[^adh]:[L'adhérence](#ladhérence)


